@@ -20,6 +20,7 @@ unset MKISOFS           || true
 unset MKISOFS_OPTS      || true
 unset ISOLINUX          || true
 unset EXCLUDE           || true
+unset NOSOURCE          || true
 unset SRCEXCLUDE        || true
 unset NORECOMMENDS      || true
 unset NOSUGGESTS        || true
@@ -50,7 +51,7 @@ unset OMIT_RELEASE_NOTES || true
 export BASEDIR=`pwd`
 
 # Building etch cd set ...
-export CODENAME=sarge
+export CODENAME=etch
 
 # By default use Debian installer packages from $CODENAME
 if [ ! "$DI_CODENAME" ]
@@ -65,7 +66,7 @@ fi
 #export DI_WWW_HOME=default
 
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="3.1"
+export DEBVERSION="3.2"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -74,8 +75,21 @@ export OFFICIAL="Unofficial"
 #export OFFICIAL="Official"
 #export OFFICIAL="Official Beta"
 
-# ... for arch  
-export ARCH=`dpkg --print-architecture`
+# ... for arch
+CPU=`dpkg-architecture -qDEB_HOST_DPKG_CPU 2>/dev/null || true`
+if [ "$CPU"x = ""x ] ; then
+    CPU=`dpkg-architecture -qDEB_HOST_ARCH`
+fi
+KERNEL=`dpkg-architecture -qDEB_HOST_DPKG_OS 2>/dev/null || true`
+if [ "$KERNEL"x = ""x ] ; then
+    KERNEL=linux
+fi
+if [ $KERNEL = linux ] ; then
+    ARCH=$CPU
+else
+    ARCH="$KERNEL-$CPU"
+fi
+export CPU KERNEL ARCH
 
 # IMPORTANT : The 4 following paths must be on the same partition/device.
 #	      If they aren't then you must set COPYLINK below to 1. This
@@ -160,7 +174,7 @@ ATTEMPT_FALLBACK=yes
 
 # Set your disk size here in MB. Used in calculating package and
 # source file layouts in build.sh and build_all.sh. Defaults are for
-# CD-R, try ~4600 for DVD-R.
+# CD-R, try ~4400 for DVD-R.
 export DEFBINSIZE=630
 export DEFSRCSIZE=635
 
@@ -174,6 +188,11 @@ export DEFSRCSIZE=635
 # We also exclude some source packages
 #export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-$CODENAME
 
+# Set this if building source packages CDs should be skipped.
+# You won't need source packages on your local mirror in that case.
+# (Setting IMAGETARGET is now deprecated, though still supported.)
+#export NOSOURCE=1
+
 # Set this if the recommended packages should be skipped when adding 
 # package on the CD.  The default is 'false'.
 export NORECOMMENDS=1
@@ -305,11 +324,6 @@ done
 # If set, overrides the boot picture used.
 #export SPLASHPNG="$BASEDIR/data/$CODENAME/splash-img.png"
 
-# Used by build.sh to determine what to build, this is the name of a target
-# in the Makefile. Use bin-official_images to build only binary CDs. The
-# default, official_images, builds everything.
-IMAGETARGET=bin-official_images
-
 # Set to 1 to save space by omitting the installation manual. 
 # If so the README will link to the manual on the web site.
 #export OMIT_MANUAL=1
@@ -320,3 +334,15 @@ export OMIT_RELEASE_NOTES=1
 
 # Set this to override the defaul location
 #export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
+
+case "$OFFICIAL"x in
+       "Official"x)
+               export OFFICIAL_VAL=2
+               ;;
+       "Official Beta"x)
+               export OFFICIAL_VAL=1
+               ;;
+       *)
+               export OFFICIAL_VAL=0
+               ;;
+esac
