@@ -21,11 +21,14 @@ if [ "$SKIPMIRRORCHECK" = "yes" ]; then
     echo " ... WARNING: skipping mirror check"
 else
     echo " ... checking your mirror"
-    make mirrorcheck-binary
-    make mirrorcheck-source
-    if [ $? -gt 0 ]; then
-	    echo "ERROR: Your mirror has a problem, please correct it." >&2
-	    exit 1
+    RET=""
+    make mirrorcheck-binary || RET=$?
+    if [ -z "$RET" ] && [ -z "$NOSOURCE" ]; then
+	make mirrorcheck-source || RET=$?
+    fi
+    if [ "$RET" ]; then
+	echo "ERROR: Your mirror has a problem, please correct it." >&2
+	exit 1
     fi
 fi
 echo " ... selecting packages to include"
@@ -56,8 +59,18 @@ for CD in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15; do
 done
 
 FULL_SIZE=`echo "($DEFSRCSIZE - $size) * 1024 * 1024" | bc`
-make list $SIZE_ARGS SRCSIZELIMIT=$FULL_SIZE
+
+LISTTARGET="list"
+if [ -n "$NOSOURCE" ] ; then
+    LISTTARGET="bin-list"
+fi
+make $LISTTARGET $SIZE_ARGS SRCSIZELIMIT=$FULL_SIZE
+
 echo " ... building the images"
+# Setting IMAGETARGET directly is deprecated; NOSOURCE is preferred
+if [ -n "$NOSOURCE" ] ; then
+    IMAGETARGET="bin-official_images"
+fi
 if [ -z "$IMAGETARGET" ] ; then
     IMAGETARGET="official_images"
 fi
